"""
authentication related helper functions
"""
import click
import json
import os
import requests
import sys
from mimir_cli.strings import API_LOGIN_URL, MIMIR_DIR, MIMIR_CREDS_PATH, ERR_NOT_AUTH
from mimir_cli.utils.io import mkdir
from mimir_cli.utils.state import debug


def login_to_mimir(email, password):
    """logs into the platform api"""
    login_request = requests.post(
        API_LOGIN_URL, data={"email": email, "password": password}
    )
    data = json.loads(login_request.text)
    debug(data)
    if data["success"]:
        cookies = login_request.cookies.get_dict()
        write_credentials(cookies)
    return data["success"]


def logout_of_mimir():
    """logs out of mimir"""
    os.remove(MIMIR_CREDS_PATH)
    return True


def read_credentials():
    """reads the user credentials from the mimir directory"""
    mkdir(MIMIR_DIR)
    if os.path.isfile(MIMIR_CREDS_PATH):
        with open(MIMIR_CREDS_PATH, "r") as mimir_credentials_file:
            credentials = json.loads(mimir_credentials_file.read())
        if credentials and (
            "user_session_id" in credentials or "api_token" in credentials
        ):
            return credentials
    click.echo(ERR_NOT_AUTH)
    sys.exit()


def write_credentials(cookies):
    """writes the user credentials to the mimir directory"""
    mkdir(MIMIR_DIR)
    credentials = json.dumps(cookies)
    with open(MIMIR_CREDS_PATH, "w") as mimir_credentials_file:
        mimir_credentials_file.write(credentials)
